@@ -70,9 +70,14 @@ class PortalBase:
         debug=False,
     ):
         self.network = network
+        """The :py:class:`~adafruit_portalbase.NetworkBase`-derived instance provided"""
         self.graphics = graphics
+        """The :py:class:`~adafruit_portalbase.GraphicsBase`-derived instance provided"""
         self.splash = self.graphics.splash
+        """The :py:meth:`displayio.Group()` object that acts as the splash screen
+        for this device."""
         self.display = self.graphics.display
+        """The :py:meth:`displayio.Display` object representing the screen for this device"""
 
         # Font Cache
         self._fonts = {}
